@@ -123,20 +123,29 @@ class DnsmasqRouted(dhcp.Dnsmasq):
         cmd.append('--dhcp-lease-max=%d' %
                    min(possible_leases, self.conf.dnsmasq_lease_max))
 
-        if self.conf.dhcp_renewal_time > 0:
-            cmd.append('--dhcp-option-force=option:T1,%ds' %
-                       self.conf.dhcp_renewal_time)
+        try:
+            if self.conf.dhcp_renewal_time > 0:
+                cmd.append('--dhcp-option-force=option:T1,%ds' %
+                           self.conf.dhcp_renewal_time)
+        except AttributeError:
+            pass
 
-        if self.conf.dhcp_rebinding_time > 0:
-            cmd.append('--dhcp-option-force=option:T2,%ds' %
-                       self.conf.dhcp_rebinding_time)
+        try:
+            if self.conf.dhcp_rebinding_time > 0:
+                cmd.append('--dhcp-option-force=option:T2,%ds' %
+                           self.conf.dhcp_rebinding_time)
+        except AttributeError:
+            pass
 
         cmd.append('--conf-file=%s' % self.conf.dnsmasq_config_file)
         for server in self.conf.dnsmasq_dns_servers:
             cmd.append('--server=%s' % server)
 
-        if self.dns_domain:
-            cmd.append('--domain=%s' % self.dns_domain)
+        try:
+            if self.dns_domain:
+                cmd.append('--domain=%s' % self.dns_domain)
+        except AttributeError:
+            pass
 
         if self.conf.dhcp_broadcast_reply:
             cmd.append('--dhcp-broadcast')
